// The Vue build version to load with the `import` command
// (runtime-only or standalone) has been set in webpack.base.conf with an alias.
import Vue from 'vue'
import FastClick from 'fastclick'
import VueRouter from 'vue-router'
import VueResource from 'vue-resource'
import App from './App.vue'
import Vuex from 'vuex'
import  {ConfirmPlugin} from 'vux'
import VueVideoPlayer from 'vue-video-player'
import  {ToastPlugin} from 'vux'
import routes from './router/routes'
import {base64} from 'vux'
import CommonUtil from './components/util/commonUtil.js'
import Actions from './lib/Actions'
import Api from './lib/api'

Vue.use(VueRouter);
Vue.use(VueResource);
Vue.use(Vuex);
Vue.use(VueVideoPlayer);
Vue.use(ToastPlugin);
Vue.use(ConfirmPlugin);

const store = new Vuex.Store({
    state: {
        isLoading: false,
        isLogIn: false,
        user: {
            name: '',
            image: ''
        },
        changeState: {
            action: null,
            action_id: -1
        },
        user_bonus: [],
        address: {
            aid: '',
            name: '',
            mobile: '',
            address: ''
        },
    },
    mutations: {
        updateLoadingStatus (state, payload) {
            state.isLoading = payload.isLoading
        },
        updateLogIn(state){
            state.isLogIn = true
        },
        updateUser(state, payload){
            state.user['name'] = payload.name;
            state.user['image'] = payload.image;
        },
        updateOrderState(state, payload){
            state.changeState.action = payload.action;
            state.changeState.action_id = payload.action_id;
        },

        updateUser_bonus(state, payload) {
            state.user_bonus = payload.array;
        },
        update_address(state, payload){
            state.address.name = payload.name;
            state.address.mobile = payload.mobile;
            state.address.address = payload.address;
            state.address.aid = payload.aid;
        }
    }
});

// Api.init_url(window.location.href);

//超时处理
Vue.http.interceptors.push((request, next) => {
    let timeout;
// 這裡改用 _timeout
    if (request._timeout) {
        timeout = setTimeout(() => {
            //自定义响应体 status:408,statustext:"请求超时"，并返回给下下边的next
            next(request.respondWith(request.body, {
                status: 408,
                statusText: '请求超时'
            }));

        }, request._timeout);
    }
    next((response) => {
        return response;
    })
});

//
const scrollBehavior = (to, from, savedPosition) => {
    if (savedPosition) {
        setTimeout(() => {
            document.body.scrollTop = savedPosition.y
        }, 100);
        return savedPosition
    }
    return {
        x: 0,
        y: 0
    };
};


const router = new VueRouter({
    routes,
    scrollBehavior,
    mode: 'history',
    base: '/mshop/'
});
//
router.beforeEach(function (to, from, next) {
    if (to.path.indexOf("schema") !== -1) {
        let schema = base64.decode(to.query.schema);
        let urlObj = CommonUtil.parseURL(schema);
        let path = urlObj.path;
        switch (path) {
            case "//p.lrlz.com/web/web":
                let title = decodeURI(urlObj.params.title);
                let url = base64.encode(decodeURIComponent(urlObj.params.url));
                next(Actions.getWebViewPath(title, url));
                break;
        }
    } else {
        next();
    }
});

FastClick.attach(document.body);

Vue.config.productionTip = false;

Vue.directive('document_title', {
    inserted: function (el, binding) {
        document.title = el.innerText;
        el.remove();
    }
});


/* eslint-disable no-new */
new Vue({
    store,
    router,
    render: h => h(App)
}).$mount('#app-box');


